==> winnie-0.1.46.tgz: package/templates/login.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var Button = require('kenga-buttons/button');
var Anchors = require('kenga-containers/anchors-pane');
var Label = require('kenga-labels/label');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var Button__default = /*#__PURE__*/_interopDefaultLegacy(Button);
var Anchors__default = /*#__PURE__*/_interopDefaultLegacy(Anchors);
var Label__default = /*#__PURE__*/_interopDefaultLegacy(Label);

var KengaWidgets = function KengaWidgets() {
  _classCallCheck__default['default'](this, KengaWidgets);

  var surface = new Anchors__default['default']();
  {
    surface.element.style.width = '300px';
    surface.element.style.height = '400px';
  }
  this.surface = surface;
  var registerByEmail = new Button__default['default']();
  {
    registerByEmail.text = 'E-Mail';
    registerByEmail.element.style.left = '60px';
    registerByEmail.element.style.width = '181px';
    registerByEmail.element.style.top = '250px';
    registerByEmail.element.style.height = '41px';
  }
  this.registerByEmail = registerByEmail;
  var logo = new Label__default['default']();
  {
    logo.text = 'Logo';
    logo.horizontalTextPosition = 'center';
    logo.element.style.left = '60px';
    logo.element.style.width = '177px';
    logo.element.style.top = '40px';
    logo.element.style.height = '118px';
  }
  this.logo = logo;
  var continueWithFacebook = new Button__default['default']();
  {
    continueWithFacebook.text = 'Facebook';
    continueWithFacebook.element.style.left = '60px';
    continueWithFacebook.element.style.width = '181px';
    continueWithFacebook.element.style.top = '190px';
    continueWithFacebook.element.style.height = '41px';
  }
  this.continueWithFacebook = continueWithFacebook;
  var alreadyRegistered = new Label__default['default']();
  {
    alreadyRegistered.text = 'Already registered ?';
    alreadyRegistered.element.style.left = '60px';
    alreadyRegistered.element.style.top = '310px';
    alreadyRegistered.element.style.height = '20px';
  }
  this.alreadyRegistered = alreadyRegistered;
  var signIn = new Label__default['default']();
  {
    signIn.text = 'Sign in here';
    signIn.element.style.left = '60px';
    signIn.element.style.top = '340px';
    signIn.element.style.height = '20px';
  }
  this.signIn = signIn;
  surface.add(logo);
  surface.add(continueWithFacebook);
  surface.add(registerByEmail);
  surface.add(alreadyRegistered);
  surface.add(signIn);
};

module.exports = KengaWidgets;

==> winnie-0.1.55.tgz: package/templates/login.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var Button = require('kenga-buttons/button');
var Anchors = require('kenga-containers/anchors-pane');
var Label = require('kenga-labels/label');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var Button__default = /*#__PURE__*/_interopDefaultLegacy(Button);
var Anchors__default = /*#__PURE__*/_interopDefaultLegacy(Anchors);
var Label__default = /*#__PURE__*/_interopDefaultLegacy(Label);

var KengaWidgets = function KengaWidgets() {
  _classCallCheck__default["default"](this, KengaWidgets);

  var surface = new Anchors__default["default"]();
  {
    surface.element.style.width = '300px';
    surface.element.style.height = '400px';
  }
  this.surface = surface;
  var registerByEmail = new Button__default["default"]();
  {
    registerByEmail.text = 'E-Mail';
    registerByEmail.element.style.left = '60px';
    registerByEmail.element.style.width = '181px';
    registerByEmail.element.style.top = '250px';
    registerByEmail.element.style.height = '41px';
  }
  this.registerByEmail = registerByEmail;
  var logo = new Label__default["default"]();
  {
    logo.text = 'Logo';
    logo.horizontalTextPosition = 'center';
    logo.element.style.left = '60px';
    logo.element.style.width = '177px';
    logo.element.style.top = '40px';
    logo.element.style.height = '118px';
  }
  this.logo = logo;
  var continueWithFacebook = new Button__default["default"]();
  {
    continueWithFacebook.text = 'Facebook';
    continueWithFacebook.element.style.left = '60px';
    continueWithFacebook.element.style.width = '181px';
    continueWithFacebook.element.style.top = '190px';
    continueWithFacebook.element.style.height = '41px';
  }
  this.continueWithFacebook = continueWithFacebook;
  var alreadyRegistered = new Label__default["default"]();
  {
    alreadyRegistered.text = 'Already registered ?';
    alreadyRegistered.element.style.left = '60px';
    alreadyRegistered.element.style.top = '310px';
    alreadyRegistered.element.style.height = '20px';
  }
  this.alreadyRegistered = alreadyRegistered;
  var signIn = new Label__default["default"]();
  {
    signIn.text = 'Sign in here';
    signIn.element.style.left = '60px';
    signIn.element.style.top = '340px';
    signIn.element.style.height = '20px';
  }
  this.signIn = signIn;
  surface.add(logo);
  surface.add(continueWithFacebook);
  surface.add(registerByEmail);
  surface.add(alreadyRegistered);
  surface.add(signIn);
};

module.exports = KengaWidgets;
